@@ -21,19 +21,20 @@ get_ipc <- function(folder = tempdir()){
 
   assertthat::assert_that(is.character(folder), msg = "Sorry... :( \n \t folder parameter must be character")
   attempt::stop_if_not(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
+
+  u <- "http://www.ine.gub.uy/c/document_library/get_file?uuid=2e92084a-94ec-4fec-b5ca-42b40d5d2826&groupId=10181"
+  f <- fs::path(folder, "IPC gral var M_B10.xls")
+  if (identical(.Platform$OS.type, "unix")) {
+    try(utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate'))
+  } else {
+    try(utils::download.file(u, f, mode = 'wb', method = 'libcurl'))
+  }
   suppressMessages({
-    u <- "http://www.ine.gub.uy/c/document_library/get_file?uuid=2e92084a-94ec-4fec-b5ca-42b40d5d2826&groupId=10181"
-    f <- fs::path(folder, "IPC gral var M_B10.xls")
-    if (identical(.Platform$OS.type, "windows")) {
-      utils::download.file(u, f, mode = 'wb', method = 'libcurl')
-    } else {
-      utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate')
-    }
-    df <- readxl::read_xls(f) %>%
-      dplyr::slice(7, 10:999)
-    names(df) <- df[1,]
-    df <- df[-1,]
-    df <- janitor::clean_names(df) %>%
+     df <- readxl::read_xls(f) %>%
+       dplyr::slice(7, 10:999)
+     names(df) <- df[1,]
+     df <- df[-1,]
+     df <- janitor::clean_names(df) %>%
       dplyr::mutate(fecha = janitor::excel_numeric_to_date(as.numeric(as.character(.data$mes_y_ano)), date_system = "modern")) %>%
       dplyr::select(.data$fecha, dplyr::everything(), -.data$mes_y_ano)
     ipc_base2010 <- df
@@ -95,20 +96,21 @@ get_ipc_region <- function(folder = tempdir(), region, sheet = 1){
   attempt::stop_if_not(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
   assertthat::assert_that(is.character(folder), msg = "Sorry... :( \n \t folder parameter must be character")
   assertthat::assert_that(region %in% c("M", "I"), msg = "Sorry... :( \n \t region parameter must be 'M' for Montevideo or 'I' for Interior")
+
+  if (region == "M") {
+    u <- "http://www.ine.gub.uy/c/document_library/get_file?uuid=c7628833-9b64-44a4-ac97-d13353ee79ac&groupId=10181"
+    f <- fs::path(folder, "IPC 3.1 indvarinc_ div M_B10_Mon.xls")
+  }
+  else {
+    u <- "http://www.ine.gub.uy/c/document_library/get_file?uuid=61f9e884-781d-44be-9760-6d69f214b5b3&groupId=10181"
+    f <- fs::path(folder, "IPC 3.2 indvarinc_ div M_B10_Int.xls")
+  }
+  if (identical(.Platform$OS.type, "unix")) {
+    try(utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate'))
+  } else {
+    try(utils::download.file(u, f, mode = 'wb', method = 'libcurl'))
+  }
   suppressMessages({
-    if (region == "M") {
-      u <- "http://www.ine.gub.uy/c/document_library/get_file?uuid=c7628833-9b64-44a4-ac97-d13353ee79ac&groupId=10181"
-      f <- fs::path(folder, "IPC 3.1 indvarinc_ div M_B10_Mon.xls")
-    }
-    else {
-      u <- "http://www.ine.gub.uy/c/document_library/get_file?uuid=61f9e884-781d-44be-9760-6d69f214b5b3&groupId=10181"
-      f <- fs::path(folder, "IPC 3.2 indvarinc_ div M_B10_Int.xls")
-    }
-    if (identical(.Platform$OS.type, "windows")) {
-      utils::download.file(u, f, mode = 'wb', method = 'libcurl')
-    } else {
-      utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate')
-    }
     df <- readxl::read_xls(f, sheet = sheet)
     df <- df[,-1] %>% janitor::remove_empty("rows")
     df <- dplyr::bind_rows(dplyr::slice(df, 1), dplyr::filter_all(df, dplyr::any_vars(grepl('ndice General', .))))
@@ -155,14 +157,15 @@ get_cba_cbna <- function(folder = tempdir(), region, sheet = 1){
   attempt::stop_if_not(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
   assertthat::assert_that(is.character(folder), msg =  "Sorry... :( \n \t folder parameter must be character")
   assertthat::assert_that(region %in% c("M", "I", "R"), msg =  "Sorry... :( \n \t region parameter must be 'M' for Montevideo, 'I' for Interior urbano or 'R' for Interior rural")
+
+  u <- "http://www.ine.gub.uy/c/document_library/get_file?uuid=1675e7d0-6fe0-49bd-bf3f-a46bd6334c0c&groupId=10181"
+  f <- fs::path(folder, "CBA_LP_LI_M.xls")
+  if (identical(.Platform$OS.type, "unix")) {
+    try(utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate'))
+  } else {
+    try(utils::download.file(u, f, mode = 'wb', method = 'libcurl'))
+  }
   suppressMessages({
-    u <- "http://www.ine.gub.uy/c/document_library/get_file?uuid=1675e7d0-6fe0-49bd-bf3f-a46bd6334c0c&groupId=10181"
-    f <- fs::path(folder, "CBA_LP_LI_M.xls")
-    if (identical(.Platform$OS.type, "windows")) {
-      utils::download.file(u, f, mode = 'wb', method = 'libcurl')
-    } else {
-      utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate')
-    }
     df <- readxl::read_xls(f, sheet = sheet)
     date <- df[9:nrow(df),1]
     names(date) <- "fecha"
@@ -220,14 +223,15 @@ get_cba_cbna <- function(folder = tempdir(), region, sheet = 1){
 get_ipab <- function(folder = tempdir(), sheet = 1){
   attempt::stop_if_not(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
   assertthat::assert_that(is.character(folder), msg =  "Sorry... :( \n \t folder parameter must be character")
+
+  u <- "http://www.ine.gub.uy/c/document_library/get_file?uuid=c4b5efaa-cdd4-497a-ab78-e3138e4f08dc&groupId=10181"
+  f <- fs::path(folder, "IPC Div M_B10.xls")
+  if (identical(.Platform$OS.type, "unix")) {
+    try(utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate'))
+  } else {
+    try(utils::download.file(u, f, mode = 'wb', method = 'libcurl'))
+  }
   suppressMessages({
-    u <- "http://www.ine.gub.uy/c/document_library/get_file?uuid=c4b5efaa-cdd4-497a-ab78-e3138e4f08dc&groupId=10181"
-    f <- fs::path(folder, "IPC Div M_B10.xls")
-    if (identical(.Platform$OS.type, "windows")) {
-      utils::download.file(u, f, mode = 'wb', method = 'libcurl')
-    } else {
-      utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate')
-    }
     df <- readxl::read_xls(f, sheet = sheet)
     df <- df[,-1:-2] %>% janitor::remove_empty("rows")
     df <- dplyr::bind_rows(dplyr::slice(df, 1), dplyr::filter_all(df, dplyr::any_vars(grepl(c('Divisiones'), .))), dplyr::filter_all(df, dplyr::any_vars(grepl(c('Alimentos y Bebidas No Alcoh'), .))))
@@ -262,19 +266,20 @@ get_ipab_region <- function(folder = tempdir(), region, sheet = 1){
   attempt::stop_if_not(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
   assertthat::assert_that(is.character(folder), msg = "Sorry... :( \n \t folder parameter must be character")
   assertthat::assert_that(region %in% c("M", "I"), msg = "Sorry... :( \n \t region parameter must be 'M' for Montevideo or 'I' for Interior")
+
+  if (region == "M") {
+    u <- "http://ine.gub.uy/c/document_library/get_file?uuid=c7628833-9b64-44a4-ac97-d13353ee79ac&groupId=10181"
+    f <- fs::path(folder, "IPC 3.1 indvarinc_ div M_B10_Mon.xls")
+  } else {
+    u <- "http://ine.gub.uy/c/document_library/get_file?uuid=61f9e884-781d-44be-9760-6d69f214b5b3&groupId=10181"
+    f <- fs::path(folder, "IPC 3.2 indvarinc_ div M_B10_Int.xls")
+  }
+  if (identical(.Platform$OS.type, "unix")) {
+    try(utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate'))
+  } else {
+    try(utils::download.file(u, f, mode = 'wb', method = 'libcurl'))
+  }
   suppressMessages({
-    if (region == "M") {
-      u <- "http://ine.gub.uy/c/document_library/get_file?uuid=c7628833-9b64-44a4-ac97-d13353ee79ac&groupId=10181"
-      f <- fs::path(folder, "IPC 3.1 indvarinc_ div M_B10_Mon.xls")
-    } else {
-      u <- "http://ine.gub.uy/c/document_library/get_file?uuid=61f9e884-781d-44be-9760-6d69f214b5b3&groupId=10181"
-      f <- fs::path(folder, "IPC 3.2 indvarinc_ div M_B10_Int.xls")
-    }
-    if (identical(.Platform$OS.type, "windows")) {
-      utils::download.file(u, f, mode = 'wb', method = 'libcurl')
-    } else {
-      utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate')
-    }
     df <- readxl::read_xls(f, sheet = sheet)
     df <- df[,-1] %>% janitor::remove_empty("rows")
     df <- dplyr::bind_rows(dplyr::slice(df, 1), dplyr::filter_all(df, dplyr::any_vars(grepl(c('Alimentos y Bebidas No Alcoh'), .))))
@@ -318,10 +323,10 @@ get_ciiu <- function(folder = tempdir(),
   attempt::stop_if_not(.x = curl::has_internet(), msg = "No internet access was detected. Please check your connection.")
   u <- "http://www.ine.gub.uy/documents/10181/33330/CORRESPONDENCIA+CIUU4+A+CIUU3.pdf/623c43cb-009c-4da9-b48b-45282745063b"
   f <- fs::path(folder, "ciiu4.pdf")
-  if (identical(.Platform$OS.type, "windows")) {
-    utils::download.file(u, f, mode = 'wb', method = 'libcurl')
+  if (identical(.Platform$OS.type, "unix")) {
+    try(utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate'))
   } else {
-    utils::download.file(u, f, mode = 'wb', method = 'wget', extra = '--no-check-certificate')
+    try(utils::download.file(u, f, mode = 'wb', method = 'libcurl'))
   }
   key <- rstudioapi::askForSecret("api_key")
   pdftables::convert_pdf(f, "ciiu4.csv",api_key = key)
@@ -488,10 +493,13 @@ age_groups <- function(data = ech::toy_ech_2018,
 #'
 #' @examples
 #' toy_ech_2018 <- organize_ht11(data = ech::toy_ech_2018, year = 2018)
-organize_ht11 <- function(data = ech::toy_ech_2018,
-                          year = 2018,
-                          ht11 = "ht11",
-                          numero = "numero"){
+
+organize_ht11 <- function(data, year, ht11 = "ht11", numero = "numero") {
+
+  assertthat::assert_that(is.data.frame(data), msg = glue:glue("Sorry... :( \n \t data parameter must be data.frame"))
+  assertthat::assert_that(is.numeric(year), msg = glue:glue("Sorry... :( \n \t year parameter must be a numeric value"))
+  assertthat::assert_that(ht11 %in% names(data), msg =  glue:glue("Sorry... :( \n \t {ht11} is not in data"))
+  assertthat::assert_that(numero %in% names(data), msg =  glue:glue("Sorry... :( \n \t {numero} is not in data"))
 
   if (year %in% 2013:2015) {
     data <- data %>%
